# -*- encoding: utf-8 -*-

#   Copyright 2005-2006 Brian McCallister
#   Copyright 2006 LogicBlaze Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

require 'stomp/constants' # Constants first
require 'stomp/ext/hash'
require 'stomp/connection'
require 'stomp/client'
require 'stomp/message'
require 'stomp/version'
require 'stomp/errors'
require 'stomp/codec'
require 'stomp/sslparams'

module Stomp
end

